#
# DecoMecha - diving decompression library.
#
# Copyright (C) 2013 by Artur Wroblewski <wrobell@pld-linux.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import ctypes as ct

lib = ct.CDLL('libdeco.so.0')
libc = ct.CDLL('libc.so.6')

# see deco.h:deco_profile_segment_t
class Segment(ct.Structure):
    _fields_ = [
        ('depth', ct.c_ubyte),
        ('time', ct.c_uint),
    ]


# see deco.h:deco_profile_t
class Profile(ct.Structure):
    _fields_ = [
        ('n_segments', ct.c_ubyte),
        ('segments', ct.POINTER(Segment)),
    ]


# see deco.h:gas_mix_t
class GasMix(ct.Structure):
    _fields_ = [
        ('depth', ct.c_ubyte),
        ('o2', ct.c_ubyte),
        ('he', ct.c_ubyte),
    ]


# see deco.h:setpoint_t
class Setpoint(ct.Structure):
    _fields_ = [
        ('depth', ct.c_ubyte),
        ('ppO2', ct.c_float),
    ]


# see deco.h:deco_conf_t
class Conf(ct.Structure):
    _fields_ = [
        ('gf_low', ct.c_ubyte),
        ('gf_high', ct.c_ubyte),
        ('pressure', ct.c_ushort),
        ('last_stop', ct.c_ubyte),
        ('n_setpoints', ct.c_ubyte),
        ('setpoints', ct.POINTER(Setpoint)),
        ('n_gas_mixes', ct.c_ubyte),
        ('gas_list', ct.POINTER(GasMix)),
    ]


# see deco.h:deco_stop_t
class Stop(ct.Structure):
    _fields_ = [
        ('depth', ct.c_ubyte),
        ('time', ct.c_ushort),
    ]


# see deco.h:deco_info_t
class Info(ct.Structure):
    _fields_ = [
        ('ndl', ct.c_ushort),
        ('n_stops', ct.c_ubyte),
        ('stops', ct.POINTER(Stop)),
    ]


lib.deco_conf_new.restype = ct.POINTER(Conf)
lib.deco_calculate.restype = ct.POINTER(Info)
lib.deco_setpoint_add.argtypes = [ct.POINTER(Conf), ct.c_ubyte, ct.c_float]
lib.deco_error.restype = ct.c_char_p


def raise_error():
    """
    Get error set by libdeco and raise appropriate exception.
    """
    errno = ct.c_int.in_dll(lib, 'deco_errno')
    if errno == 1:
        raise MemoryError('Cannot allocate memory')
    else:
        raise ValueError(lib.deco_error(errno).decode())


# vim: sw=4:et:ai
