#
# DecoMecha - diving decompression library.
#
# Copyright (C) 2013 by Artur Wroblewski <wrobell@pld-linux.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Sanity unit tests of decompression calculation for altitude (surface
pressure) changes.
"""

from decomecha import DecoEngine

from .util import TestCase
        

class AltitudeChangeTestCase(TestCase):
    """
    Sanity unit tests for altitude changes.
    """
    def test_via_pressure(self):
        """
        Test deco change due to altitude (via pressure)
        """
        d1 = DecoEngine()
        d1.pressure = 931
        d1.add_segment(45, 25)
        d1.add_gas(0, 21)
        i1 = d1.calculate()

        d2 = DecoEngine()
        d2.pressure = 1013
        d2.add_segment(45, 25)
        d2.add_gas(0, 21)
        i2 = d2.calculate()

        self._verify(i1, i2, 6)


    def test_via_altitude(self):
        """
        Test deco change due to altitude (via pressure)
        """
        d1 = DecoEngine()
        d1.altitude = 700
        d1.add_segment(45, 25)
        d1.add_gas(0, 21)
        i1 = d1.calculate()

        d2 = DecoEngine()
        d2.altitude = 0
        d2.add_segment(45, 25)
        d2.add_gas(0, 21)
        i2 = d2.calculate()

        self._verify(i1, i2, 6)


    def test_ndl(self):
        """
        Test dive NDL change due to altitude change
        """
        d1 = DecoEngine()
        d1.altitude = 700
        d1.add_segment(20, 25)
        d1.add_gas(0, 21)
        i1 = d1.calculate()

        d2 = DecoEngine()
        d2.altitude = 0
        d2.add_segment(20, 20)
        d2.add_gas(0, 21)
        i2 = d2.calculate()

        self.assertTrue(i1.ndl < i2.ndl, '{} vs {}'.format(i1.ndl, i2.ndl))



# vim: sw=4:et:ai
