#
# DecoMecha - diving decompression library.
#
# Copyright (C) 2013 by Artur Wroblewski <wrobell@pld-linux.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Shorter dive sanity unit tests. 
"""

from decomecha import DecoEngine

from .util import TestCase


class ShorterDiveTestCase(TestCase):
    """
    Shorter dive sanity unit tests.
    """
    def test_oc_air(self):
        """
        Test shorter OC dive on air
        """
        d1 = DecoEngine()
        d1.add_segment(45, 25)
        d1.add_gas(0, 21)
        i1 = d1.calculate()

        d2 = DecoEngine()
        d2.add_segment(45, 20)
        d2.add_gas(0, 21)
        i2 = d2.calculate()

        assert len(i1.stops) > 0
        assert len(i2.stops) > 0

        self._verify(i1, i2, 12)


    def test_oc_ean(self):
        """
        Test shorter OC dive on EAN 32
        """
        d1 = DecoEngine()
        d1.add_segment(32, 30)
        d1.add_gas(0, 21)
        i1 = d1.calculate()

        d2 = DecoEngine()
        d2.add_segment(32, 25)
        d2.add_gas(0, 21)
        i2 = d2.calculate()

        assert len(i1.stops) > 0
        assert len(i2.stops) > 0

        self._verify(i1, i2, 9, exclude={12,})


    def test_oc_tx(self):
        """
        Test shorter OC dive on TX 18/45
        """
        d1 = DecoEngine()
        d1.add_segment(32, 30)
        d1.add_gas(0, 18, 45)
        i1 = d1.calculate()

        d2 = DecoEngine()
        d2.add_segment(32, 25)
        d2.add_gas(0, 18, 45)
        i2 = d2.calculate()

        assert len(i1.stops) > 0
        assert len(i2.stops) > 0

        self._verify(i1, i2, 12)


    def test_ccr_air(self):
        """
        Test shorter CCR dive on Air
        """
        d1 = DecoEngine()
        d1.add_segment(35, 50)
        d1.add_gas(0, 21)
        d1.add_setpoint(0, 1.3)
        i1 = d1.calculate()

        d2 = DecoEngine()
        d2.add_segment(35, 45)
        d2.add_gas(0, 21)
        d2.add_setpoint(0, 1.3)
        i2 = d2.calculate()

        assert len(i1.stops) > 0
        assert len(i2.stops) > 0

        self._verify(i1, i2, 6)


    def test_ccr_ean(self):
        """
        Test shorter CCR dive on EAN 32
        """
        d1 = DecoEngine()
        d1.add_segment(35, 50)
        d1.add_gas(0, 32)
        d1.add_setpoint(0, 1.3)
        i1 = d1.calculate()

        d2 = DecoEngine()
        d2.add_segment(35, 45)
        d2.add_gas(0, 32)
        d2.add_setpoint(0, 1.3)
        i2 = d2.calculate()

        assert len(i1.stops) > 0
        assert len(i2.stops) > 0

        self._verify(i1, i2, 6)


    def test_ccr_tx(self):
        """
        Test shorter CCR dive on TX 18/45
        """
        d1 = DecoEngine()
        d1.add_segment(35, 50)
        d1.add_gas(0, 18, 45)
        d1.add_setpoint(0, 1.3)
        i1 = d1.calculate()

        d2 = DecoEngine()
        d2.add_segment(35, 40)
        d2.add_gas(0, 18, 45)
        d2.add_setpoint(0, 1.3)
        i2 = d2.calculate()

        assert len(i1.stops) > 0
        assert len(i2.stops) > 0

        self._verify(i1, i2, 12)


# vim: sw=4:et:ai
